@@ -14,6 +14,8 @@ typedef enum {
 
 void draw_next_balls(void);
 void draw_ball(gint ballcolor, gint x, gint y, gint jumpnum, gint destroynum);
+void redraw_ball(gint x, gint y);
+void redraw_pointer(void);
 void draw_board(void);
 /* Refill the screen from the backing pixmap */
 gint expose_event(GtkWidget *widget, GdkEventExpose *event);
