@@ -41,5 +41,9 @@ GtkWidget *ut_spin_button_start_new    (gchar *label,
 				 	gint max,
 				 	gint val,
 					GtkWidget *parent);
+void ut_simple_message_box	(gchar *message);
+
+void ut_simple_message_box_with_title	(gchar *message,
+					 gchar *title);
 
 #endif
