@@ -16,5 +16,15 @@ gint pref_get_show_footprints(void);
 void pref_set_show_footprints(gint val);
 gint pref_get_show_destroy(void);
 void pref_set_show_destroy(gint val);
+gint pref_get_show_highlight(void);
+void pref_set_show_highlight(gint val);
+
+gint prefs_get_hl_dr(void);
+void prefs_set_hl_dr(gint dr);
+gint prefs_get_hl_dg(void);
+void prefs_set_hl_dg(gint dg);
+gint prefs_get_hl_db(void);
+void prefs_set_hl_db(gint db);
+
 
 #endif /* __PREFS_H */
